==> sqlitedbms-0.2.0.tar.gz: sqlitedbms-0.2.0/src/htdocs/client/js/db.js <==
var _dbName='';
var _dbNameTmp='';
var _dbPool=[];

function dbConn(sql, callback, errCallback) {
	this.con=new XMLHttp(dbResponse);
	this.con.setData(this);
	this.con.setAsync(false);
	this.sql=sql;
	this.callback=callback;
	this.errCallback=errCallback;
	this.status='SLEEP';

	this.box=null;
	this.boxTab='';
	this.boxTabProc='';
	this.persistent=false;

	this.working=function() {
		return this.con.working();
	};

	this.exec=function(sql) {
		if (!sql) sql=this.sql;
		this.con.resetContent();
		this.con.setContent('query='+sql);
		this.con.execute();
	};

	this.setArgv=function(sql, callback, errCallback) {
		this.sql=sql;
		this.callback=callback;
		this.errCallback=errCallback;
	};

	this.setBox=function(mdi) {
		this.box=mdi;
	};
}

function dbResponse(db) {
	if (db && db.success()) {
		//alert(db.status()+' '+db.data.sql);
		switch (db.status()) {
			case 200:
				var data=db.getTree();
				if (db.data.callback)
					db.data.callback(data, db.data);
			break;
			default:
				var data=db.getTree();
				if (data.message && data.message[0]) {
					if (db.data.errCallback)
						db.data.errCallback(data, db.data);
					else
						alert('Error: '+data.message[0]);
				}else{
					if (db.data.errCallback)
						db.data.errCallback(null, db.data);
					else
						alert('Error: '+db.data.sql);
				}
			break;
		}
		db.data.status='SLEEP';
	}
}

function dbExecCommand(sql, callback, errCallback) {
	for (var i=_dbPool.length; i--;) {
		if (!_dbPool[i].persistent && _dbPool[i].status == 'SLEEP') {
			_dbPool[i].status='WORKING';
			_dbPool[i].setArgv(sql, callback, errCallback);
			_dbPool[i].exec();
			return _dbPool[i];
		}
	}
	var db=new dbConn(sql, callback, errCallback);
	_dbPool.push(db);
	db.status='WORKING';
	db.exec();
	return db;
}

function dbGetPool() {
	for (var i=_dbPool.length; i--;) {
		if (!_dbPool[i].persistent && _dbPool[i].status == 'SLEEP') {
			_dbPool[i].status='WORKING';
			return _dbPool[i];
		}
	}
	var db=new dbConn();
	_dbPool.push(db);
	db.status='WORKING';
	return db;
}

var _dbShowSQLCurDiv=null;
var _dbShowSQL_FFBug='';
function dbShowSQL(sql) {
	_dbShowSQLCurDiv=_curDiv;
	lGo('showSqlWin');
	var form=document.forms['form_showsql'];
	form['sql'].value=sql;
	return false;
}

function dbShowSQLCopy() {
	var form=document.forms['form_showsql'];
	var sql=form['sql'].value;

	copy_clip(sql);
}

function dbShowSQLHide() {
	if (_dbShowSQLCurDiv && _dbShowSQLCurDiv.id) {
		if (_isIE)
			_dbShowSQL_FFBug='';
		lGo(_dbShowSQLCurDiv.id);
	}else
		lHide();
}

==> sqlitedbms-0.3.0.tar.gz: sqlitedbms-0.3.0/src/htdocs/client/js/db.js <==
var _dbName='';
var _dbNameTmp='';
var _dbPool=[];

function dbConn(sql, callback, errCallback, callbackData) {
	this.con=new XMLHttp(dbResponse);
	this.con.setData(this);
	this.con.setAsync(false);
	this.sql=sql;
	this.callback=callback;
	this.callbackData=callbackData;
	this.errCallback=errCallback;
	this.status='SLEEP';

	this.box=null;
	this.boxTab='';
	this.boxTabProc='';
	this.persistent=false;

	this.working=function() {
		return this.con.working();
	};

	this.exec=function(sql) {
		if (!sql) sql=this.sql;
		this.con.resetContent();
		this.con.setContent('query='+sql);
		this.con.execute();
	};

	this.setArgv=function(sql, callback, errCallback, callbackData) {
		this.sql=sql;
		this.callback=callback;
		this.errCallback=errCallback;
		this.callbackData=callbackData;
	};

	this.setBox=function(mdi) {
		this.box=mdi;
	};
}

function dbResponse(db) {
	if (db && db.success()) {
		//alert(db.status()+' '+db.data.sql);
		switch (db.status()) {
			case 200:
				var data=db.getTree();
				if (db.data.callback)
					db.data.callback(data, db.data);
				if (data.time)
					window.status=data.time[0]+': '+db.data.sql;
			break;
			default:
				var data=db.getTree();
				if (data.message && data.message[0]) {
					if (db.data.errCallback)
						db.data.errCallback(data, db.data);
					else
						alert('Error: '+data.message[0]);
				}else{
					if (db.data.errCallback)
						db.data.errCallback(null, db.data);
					else
						alert('Error: '+db.data.sql);
				}
			break;
		}
		db.data.status='SLEEP';
	}
}

function dbExecCommand(sql, callback, errCallback, callbackData) {
	for (var i=_dbPool.length; i--;) {
		if (!_dbPool[i].persistent && _dbPool[i].status == 'SLEEP') {
			_dbPool[i].status='WORKING';
			_dbPool[i].setArgv(sql, callback, errCallback, callbackData);
			_dbPool[i].exec();
			return _dbPool[i];
		}
	}
	var db=new dbConn(sql, callback, errCallback, callbackData);
	_dbPool.push(db);
	db.status='WORKING';
	db.exec();
	return db;
}

function dbGetPool() {
	for (var i=_dbPool.length; i--;) {
		if (!_dbPool[i].persistent && _dbPool[i].status == 'SLEEP') {
			_dbPool[i].status='WORKING';
			return _dbPool[i];
		}
	}
	var db=new dbConn();
	_dbPool.push(db);
	db.status='WORKING';
	return db;
}

var _dbShowSQLCurDiv=null;
var _dbShowSQL_FFBug='';
function dbShowSQL(sql) {
	_dbShowSQLCurDiv=_curDiv;
	lGo('showSqlWin');
	var form=document.forms['form_showsql'];
	form['sql'].value=sql;
	return false;
}

function dbShowSQLCopy() {
	var form=document.forms['form_showsql'];
	var sql=form['sql'].value;

	copy_clip(sql);
}

function dbShowSQLHide() {
	if (_dbShowSQLCurDiv && _dbShowSQLCurDiv.id) {
		if (_isIE)
			_dbShowSQL_FFBug='';
		lGo(_dbShowSQLCurDiv.id);
	}else
		lHide();
}
